<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>AboutBox</name>
    <message>
        <location filename="../ui/src/aboutbox.ui" line="33"/>
        <source>About Q Light Controller Plus</source>
        <translation>Over Q Light Controller Plus</translation>
    </message>
    <message>
        <location filename="../ui/src/aboutbox.ui" line="88"/>
        <source>Contributors</source>
        <translation>Bijdragers</translation>
    </message>
    <message>
        <location filename="../ui/src/aboutbox.ui" line="135"/>
        <source>This application is licensed under the terms of the Apache 2.0 license.</source>
        <translation>Dit programma valt onder de Apache versie 2.0 licentie.</translation>
    </message>
    <message>
        <location filename="../ui/src/aboutbox.cpp" line="42"/>
        <source>and contributors:</source>
        <translation>en bijdragers:</translation>
    </message>
    <message>
        <location filename="../ui/src/aboutbox.cpp" line="43"/>
        <source>Website: %1</source>
        <translation>Website: %1</translation>
    </message>
</context>
<context>
    <name>AddChannelsDialog</name>
    <message>
        <location filename="addchannelsdialog.ui" line="33"/>
        <source>Fixture Mode Channels Editor</source>
        <translation>Fixture Mode Kanalen Editor</translation>
    </message>
    <message>
        <location filename="addchannelsdialog.ui" line="114"/>
        <source>Available channels</source>
        <oldsource>All channels</oldsource>
        <translation>Beschikbare kanalen</translation>
    </message>
    <message>
        <location filename="addchannelsdialog.ui" line="106"/>
        <location filename="addchannelsdialog.ui" line="135"/>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location filename="addchannelsdialog.ui" line="121"/>
        <source>Mode channels</source>
        <translation>Mode kanalen</translation>
    </message>
</context>
<context>
    <name>App</name>
    <message>
        <location filename="app.cpp" line="122"/>
        <source>Unrecognized file extension: %1</source>
        <translation>Onbekende bestandsextensie: %1</translation>
    </message>
    <message>
        <location filename="app.cpp" line="146"/>
        <source>Fixture loading failed</source>
        <translation>Fout bij inladen fixture</translation>
    </message>
    <message>
        <location filename="app.cpp" line="147"/>
        <source>Unable to load fixture definition: </source>
        <translation>Inladen fixturedefinitie niet gelukt: </translation>
    </message>
    <message>
        <location filename="app.cpp" line="241"/>
        <source>&amp;New</source>
        <translation>&amp;Nieuw</translation>
    </message>
    <message>
        <location filename="app.cpp" line="242"/>
        <source>CTRL+N</source>
        <comment>File|New</comment>
        <translatorcomment>Bestand|Nieuw</translatorcomment>
        <translation>CTRL+N</translation>
    </message>
    <message>
        <location filename="app.cpp" line="247"/>
        <source>&amp;Open</source>
        <translation>&amp;Open</translation>
    </message>
    <message>
        <location filename="app.cpp" line="248"/>
        <source>CTRL+O</source>
        <comment>File|Open</comment>
        <translatorcomment>Bestand|Openen</translatorcomment>
        <translation>CTRL+O</translation>
    </message>
    <message>
        <location filename="app.cpp" line="253"/>
        <source>&amp;Save</source>
        <translation>Op&amp;slaan</translation>
    </message>
    <message>
        <location filename="app.cpp" line="254"/>
        <source>CTRL+S</source>
        <comment>File|Save</comment>
        <translatorcomment>Bestand|Opslaan</translatorcomment>
        <translation>CTRL+S</translation>
    </message>
    <message>
        <location filename="app.cpp" line="259"/>
        <source>Save &amp;As...</source>
        <translation>Opslaan &amp;Als...</translation>
    </message>
    <message>
        <location filename="app.cpp" line="260"/>
        <source>CTRL+SHIFT+S</source>
        <comment>File|Save As...</comment>
        <translatorcomment>Bestand|Opslaan als...</translatorcomment>
        <translation>CTRL+SHIFT+S</translation>
    </message>
    <message>
        <location filename="app.cpp" line="265"/>
        <source>&amp;Quit</source>
        <translation>S&amp;luiten</translation>
    </message>
    <message>
        <location filename="app.cpp" line="266"/>
        <source>CTRL+Q</source>
        <comment>File|Quit</comment>
        <translatorcomment>Bestand|Sluiten</translatorcomment>
        <translation>CTRL+L</translation>
    </message>
    <message>
        <location filename="app.cpp" line="272"/>
        <source>Index</source>
        <translation>Index</translation>
    </message>
    <message>
        <location filename="app.cpp" line="273"/>
        <source>SHIFT+F1</source>
        <comment>Help|Index</comment>
        <translatorcomment>Help|Index</translatorcomment>
        <translation>SHIFT+F1</translation>
    </message>
    <message>
        <location filename="app.cpp" line="278"/>
        <source>About Fixture Definition Editor...</source>
        <translation>Over Fixture Definition Editor...</translation>
    </message>
    <message>
        <location filename="app.cpp" line="283"/>
        <source>About Qt...</source>
        <translation>Over Qt...</translation>
    </message>
    <message>
        <location filename="app.cpp" line="310"/>
        <source>&amp;File</source>
        <translation>&amp;Bestand</translation>
    </message>
    <message>
        <location filename="app.cpp" line="320"/>
        <source>&amp;Help</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <location filename="app.cpp" line="358"/>
        <source>Open a fixture definition</source>
        <translation>Open een fixture definitie</translation>
    </message>
</context>
<context>
    <name>CapabilityWizard</name>
    <message>
        <location filename="capabilitywizard.ui" line="33"/>
        <source>Capability Wizard</source>
        <translation>Capability wizard</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="39"/>
        <source>Values</source>
        <translation>Waarden</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="45"/>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="52"/>
        <source>The starting DMX value</source>
        <translation>De DMX startwaarde</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="62"/>
        <source>Width</source>
        <translation>Breedte</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="69"/>
        <source>Number of values per capability</source>
        <translation>Aantal waarden per capability</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="85"/>
        <source>Amount</source>
        <translation>Hoeveelheid</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="92"/>
        <source>Number of capabilities to create</source>
        <translation>Aantal te creëen capabilities</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="108"/>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="114"/>
        <source>The common base name for all capabilities. Use hash &apos;#&apos; to create a running number.</source>
        <translation>De gemeenschappelijke basisnaam voor alle capabilities. Gebruik hekje &apos;#&apos; voor doorlopende nummers.</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="117"/>
        <source>Capability #</source>
        <translation>Capability #</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="127"/>
        <source>Sample</source>
        <translation>Voorbeeld</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="133"/>
        <source>A list of capabilities that would be created with these settings</source>
        <translation>Een lijst van capabilities die gemaakt zou worden met de huidige instellingen</translation>
    </message>
</context>
<context>
    <name>DocBrowser</name>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="106"/>
        <source>%1 - Document Browser</source>
        <translation>%1 - Documentenbrowser</translation>
    </message>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="128"/>
        <source>Backward</source>
        <translation>Vorige</translation>
    </message>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="129"/>
        <source>Forward</source>
        <translation>Volgende</translation>
    </message>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="130"/>
        <source>Index</source>
        <translation>Index</translation>
    </message>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="131"/>
        <source>About Qt</source>
        <translation>Over Qt</translation>
    </message>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="132"/>
        <source>Close this window</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditChannel</name>
    <message>
        <location filename="editchannel.ui" line="33"/>
        <source>Edit Channel</source>
        <translation>Bewerk kanaal</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="114"/>
        <source>&lt;font color=&quot;red&quot;&gt;&lt;b&gt;Capability overlapping detected. Please fix.&lt;/b&gt;&lt;/font&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="198"/>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="240"/>
        <source>Default value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="253"/>
        <source>Type</source>
        <translation type="unfinished">Soort</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="260"/>
        <location filename="editchannel.ui" line="303"/>
        <source>Preset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="267"/>
        <source>The name of this channel</source>
        <translation>Naam van dit kanaal</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="274"/>
        <source>Role</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="336"/>
        <source>Color 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="360"/>
        <source>Color 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="387"/>
        <source>Value 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="401"/>
        <source>Value 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="430"/>
        <source>Preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="227"/>
        <source>The group this channel belongs to</source>
        <translation>Groep waaraan dit kanaal toebehoort</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="322"/>
        <source>Picture</source>
        <translation>Afbeelding</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="283"/>
        <source>Coarse (MSB)</source>
        <translation>Grof (MSB)</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="290"/>
        <source>Fine (LSB)</source>
        <translation>Fijn (LSB)</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="55"/>
        <source>Capabilities</source>
        <translation>Mogelijkheden/functies</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="90"/>
        <location filename="editchannel.cpp" line="572"/>
        <source>Minimum value</source>
        <translation>Minimumwaarde</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="95"/>
        <location filename="editchannel.cpp" line="572"/>
        <source>Maximum value</source>
        <translation>Maximumwaarde</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="100"/>
        <location filename="editchannel.cpp" line="572"/>
        <source>Description</source>
        <translation>Omschrijving</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="154"/>
        <source>Remove the selected capability</source>
        <translation>Verwijder de geselecteerde capability</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="121"/>
        <source>Capability wizard</source>
        <translation>Capability wizard</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="93"/>
        <source>Edit Channel: </source>
        <translation>Bewerk kanaal:</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="481"/>
        <source>Overlapping values</source>
        <translation>Overlappende waarden</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="498"/>
        <source>Open Gobo File</source>
        <translation>Open Gobo afbeelding</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="501"/>
        <source>Gobo pictures</source>
        <translation>Gobo-afbeeldingen</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="615"/>
        <source>Missing resources</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="616"/>
        <source>Some gobos are missing:

</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="482"/>
        <source>Some capabilities could not be created because of overlapping values.</source>
        <translation>Sommige capabilities konden niet worden aangemaakt wegens overlappende waarden.</translation>
    </message>
</context>
<context>
    <name>EditHead</name>
    <message>
        <location filename="edithead.ui" line="33"/>
        <source>Edit Head</source>
        <translation>Wijzig head</translation>
    </message>
    <message>
        <location filename="edithead.ui" line="52"/>
        <source>Channel</source>
        <translation>Kanaal</translation>
    </message>
    <message>
        <location filename="edithead.ui" line="57"/>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
</context>
<context>
    <name>EditMode</name>
    <message>
        <location filename="editmode.ui" line="33"/>
        <source>Edit Mode</source>
        <translation>Wijzig mode</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="39"/>
        <source>Mode Name</source>
        <translation>Mode naam</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="53"/>
        <source>Channels</source>
        <translation>Kanalen</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="161"/>
        <source>Number</source>
        <translation>Nummer</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="166"/>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="79"/>
        <source>Add channel(s) to this mode</source>
        <translation>Voeg een of meerdere kanalen toe aan deze mode</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="59"/>
        <source>Remove the selected channel</source>
        <translation>Verwijder het geselecteerde kanaal</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="99"/>
        <source>Raise the selected channel</source>
        <translation>Verplaats dit kanaal naar boven</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="119"/>
        <source>Lower the selected channel</source>
        <translation>Verplaats dit kanaal naar beneden</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="171"/>
        <source>Acts On</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editmode.ui" line="193"/>
        <source>Heads</source>
        <translation>Heads</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="206"/>
        <source>Head</source>
        <translation>Head</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="214"/>
        <source>Compose a new head</source>
        <translation>Maak een nieuwe head</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="234"/>
        <source>Remove the selected head</source>
        <translation>Verwijder de geselecteerde head</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="254"/>
        <source>Edit the channels that belong to the selected head</source>
        <translation>Wijzig de kanalen die toebehoren aan de geselecteerde head</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="274"/>
        <source>Raise the selected head</source>
        <translation>Verplaats de geselecteerde head naar boven</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="294"/>
        <source>Lower the selected head</source>
        <translation>Verplaats de geselecteerde head naar beneden</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="328"/>
        <source>Physical</source>
        <translation>Fysiek</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="338"/>
        <source>Use global settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editmode.ui" line="348"/>
        <source>Override global settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditPhysical</name>
    <message>
        <location filename="editphysical.ui" line="277"/>
        <source>Bulb</source>
        <translation>Lamp</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="45"/>
        <location filename="editphysical.ui" line="283"/>
        <source>Type</source>
        <translation>Soort</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="515"/>
        <source>Lumens</source>
        <translation>Lumen</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="535"/>
        <source>Colour Temp (K)</source>
        <translation>Kleurtemperatuur (K)</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="708"/>
        <source>Dimensions</source>
        <translation>Afmetingen</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="784"/>
        <source>Weight</source>
        <translation>Gewicht</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="714"/>
        <source>kg</source>
        <translation>kg</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="724"/>
        <source>Width</source>
        <translation>Breedte</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="734"/>
        <location filename="editphysical.ui" line="754"/>
        <location filename="editphysical.ui" line="774"/>
        <source>mm</source>
        <translation>mm</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="744"/>
        <source>Height</source>
        <translation>Hoogte</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="764"/>
        <source>Depth</source>
        <translation>Diepte</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="39"/>
        <source>Head(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="630"/>
        <source>Lens</source>
        <translation>Lens</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="636"/>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="665"/>
        <source>Min Degrees</source>
        <translation>Min Graden</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="672"/>
        <source>Max Degrees</source>
        <translation>Max Graden</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="79"/>
        <source>Pan Max Degrees</source>
        <translation>Pan Max Graden</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="96"/>
        <source>Tilt Max Degrees</source>
        <translation>Tilt Max Graden</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="113"/>
        <source>Layout
(Columns x Rows)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="158"/>
        <source>Electrical</source>
        <translation>Elektrisch</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="164"/>
        <source>Power Consumption</source>
        <translation>Stroomverbruik</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="174"/>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="184"/>
        <source>DMX Connector</source>
        <translation>DMX connector</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="241"/>
        <source>Copy physical information to clipboard</source>
        <translation>Kopieer de fysieke informatie naar het klembord</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="258"/>
        <source>Paste physical information from clipboard</source>
        <translation>Plak de fysieke informatie van het klembord</translation>
    </message>
</context>
<context>
    <name>FixtureEditor</name>
    <message>
        <location filename="fixtureeditor.ui" line="33"/>
        <source>Fixture</source>
        <translation>Fixture</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="43"/>
        <source>General</source>
        <translation>Algemeen</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="55"/>
        <source>Manufacturer</source>
        <translation>Fabrikant</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="68"/>
        <source>The manufacturer name for this fixture (e.g. Martin)</source>
        <translation>De naam van de fabrikant van deze fixture (bijv. Martin)</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="75"/>
        <source>Model</source>
        <translation>Model</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="88"/>
        <source>The model name for this fixture (e.g. MAC250)</source>
        <translation>De naam van dit model fixture (bijv. MAC250)</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="95"/>
        <source>Type</source>
        <translation>Soort</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="108"/>
        <source>The general type of this fixture</source>
        <translation>De soort fixture in het algemeen</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="247"/>
        <source>Author</source>
        <translation>Auteur</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="254"/>
        <source>The name of the author of this fixture definition</source>
        <translation>De auteur van deze fixturedefinitie</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="298"/>
        <location filename="fixtureeditor.ui" line="498"/>
        <source>Channels</source>
        <translation>Kanalen</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="320"/>
        <location filename="fixtureeditor.ui" line="493"/>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="325"/>
        <source>Group</source>
        <translation>Groep</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="333"/>
        <source>Add a channel</source>
        <translation>Voeg een kanaal toe</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="353"/>
        <source>Remove the selected channel</source>
        <translation>Verwijder het geselecteerde kanaal</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="373"/>
        <source>Edit the selected channel</source>
        <translation>Wijzig het geselecteerde kanaal</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="400"/>
        <source>Copy the selected channel to the clipboard</source>
        <translation>Kopieer het geselecteerde kanaal naar het klembord</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="420"/>
        <source>Paste the channel in clipboard to this fixture</source>
        <translation>Plak het kanaal van het klembord</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="453"/>
        <source>Open/close all channel items</source>
        <translation>Open/Sluit alle items van het kanaal</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="474"/>
        <source>Modes</source>
        <translation>Modes</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="503"/>
        <source>Heads</source>
        <translation>Heads</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="511"/>
        <source>Add a mode</source>
        <translation>Voeg een mode toe</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="531"/>
        <source>Remove the selected mode</source>
        <translation>Verwijder de geselecteerde mode</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="551"/>
        <source>Edit the selected mode</source>
        <translation>Wijizg de geselecteerde mode</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="578"/>
        <source>Create a copy of the selected mode</source>
        <translation>Kopieer de geselecteerde mode</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="611"/>
        <source>Open/close all mode items</source>
        <translation>Open/Sluit alle items van deze mode</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="632"/>
        <source>Aliases</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="650"/>
        <source>In mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="667"/>
        <source>Add a new alias</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="687"/>
        <source>with</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="694"/>
        <source>replace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="711"/>
        <location filename="fixtureeditor.ui" line="764"/>
        <source>Alias</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="716"/>
        <source>Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="721"/>
        <source>Base channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="726"/>
        <source>Override channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="744"/>
        <source>Remove the currently selected alias</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="275"/>
        <source>Physical</source>
        <translation type="unfinished">Fysiek</translation>
    </message>
</context>
<context>
    <name>QLCFixtureEditor</name>
    <message>
        <location filename="fixtureeditor.cpp" line="207"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="208"/>
        <source>Do you want to save changes to fixture
&quot;%1&quot;
before closing?</source>
        <translation>Wil je voor het sluiten de wijzigingen opslaan van fixture %1?</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="237"/>
        <location filename="fixtureeditor.cpp" line="247"/>
        <source>Missing important information</source>
        <translation>Belangrijke informatie ontbreekt</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="238"/>
        <source>Missing manufacturer name.
Unable to save fixture.</source>
        <translation>Naam van de fabrikant ontbreekt. Opslaan van deze fixture is niet mogelijk.</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="248"/>
        <source>Missing fixture model name.
Unable to save fixture.</source>
        <translation>Naam van het model ontbreekt. Opslaan van deze fixture is niet mogelijk.</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="278"/>
        <location filename="fixtureeditor.cpp" line="337"/>
        <source>Fixture saving failed</source>
        <translation>Opslaan fixture mislukt</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="279"/>
        <location filename="fixtureeditor.cpp" line="338"/>
        <source>Unable to save fixture definition:
%1</source>
        <translation>Fixturedefinitie %1 kan niet opgeslagen worden</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="294"/>
        <source>Save fixture definition</source>
        <translation>Sla fixture definite op</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="371"/>
        <source>New Fixture</source>
        <translation>Nieuwe Fixture</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="448"/>
        <location filename="fixtureeditor.cpp" line="548"/>
        <source>Channel already exists</source>
        <translation>Kanaal bestaat al</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="449"/>
        <location filename="fixtureeditor.cpp" line="549"/>
        <source>A channel by the name &quot;%1&quot; already exists!</source>
        <translation>Een kanaal met de naam &quot;%1&quot; bestaat al!</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="456"/>
        <location filename="fixtureeditor.cpp" line="555"/>
        <source>Channel has no name</source>
        <translation>Naam van het kanaal ontbreekt</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="457"/>
        <location filename="fixtureeditor.cpp" line="556"/>
        <source>You must give the channel a descriptive name!</source>
        <translation>Je moet het kanaal een naam geven!</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="494"/>
        <source>Are you sure you wish to remove channel: %1?</source>
        <translation>Kanaal verwijderen: %1?</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="827"/>
        <source>Are you sure you wish to remove mode: %1?</source>
        <translation>Verwijder mode %1?</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="668"/>
        <location filename="fixtureeditor.cpp" line="703"/>
        <location filename="fixtureeditor.cpp" line="928"/>
        <source>Edit</source>
        <translation>Wijzig</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="669"/>
        <location filename="fixtureeditor.cpp" line="705"/>
        <source>Copy</source>
        <translation>Kopiëren</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="670"/>
        <location filename="fixtureeditor.cpp" line="707"/>
        <source>Paste</source>
        <translation>Plakken</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="671"/>
        <location filename="fixtureeditor.cpp" line="709"/>
        <location filename="fixtureeditor.cpp" line="934"/>
        <source>Remove</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="682"/>
        <source>Channels</source>
        <translation>Kanalen</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="780"/>
        <location filename="fixtureeditor.cpp" line="789"/>
        <source>Unable to add mode</source>
        <translation>Toevoegen mode niet mogelijk</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="781"/>
        <source>Another mode by that name already exists</source>
        <translation>Een mode met deze naam bestaat al</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="790"/>
        <source>You must give a name to the mode</source>
        <translation>De mode moet een naam hebben</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="826"/>
        <source>Remove Mode</source>
        <translation>Verwijder mode</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="874"/>
        <source>Rename new mode</source>
        <translation>Hernoem nieuwe mode</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="875"/>
        <source>Give a unique name for the mode</source>
        <translation>Geef de mode een unieke naam</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="877"/>
        <source>Copy of %1</source>
        <translation>Kopie van %1</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="887"/>
        <source>Invalid name</source>
        <translation>Ongeldige naam</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="888"/>
        <source>Another mode by that name already exists.</source>
        <translation>Een mode met dezelfde naam bestaat al.</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="931"/>
        <source>Clone</source>
        <translation>Klonen</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="939"/>
        <source>Modes</source>
        <translation>Modes</translation>
    </message>
</context>
</TS>
